@@ -585,11 +585,6 @@ class EventHandler(object):
                 targets=targets,
             )
 
-            for b_chan in ringing_dials:
-                # To prevent notifications from being sent multiple
-                # times, we set a flag on all communicated channels.
-                b_chan.custom['ignore_b_dial'] = True
-
     def on_bridge_enter(self, channel, bridge):
         """
         Post-process a BridgeEnter event to notify of a call in progress.
